###

    Build Log

    Build started: Project: tclibutils, Configuration: Debug|Win32

    Command Lines
      Creating temporary file "d:\Avinash\work\clibutils\win\tclibutils_Debug\RSP0000173148808.rsp" with contents
    [
    /OUT:"D:\Avinash\work\clibutils\win\tclibutils_Debug\tclibutils.exe" /INCREMENTAL /LIBPATH:"clibutils_Debug" /MANIFEST /MANIFESTFILE:"tclibutils_Debug\tclibutils.exe.intermediate.manifest" /DEBUG /PDB:"d:\Avinash\work\clibutils\win\tclibutils_Debug\tclibutils.pdb" /SUBSYSTEM:CONSOLE /MACHINE:X86 clibutils.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib

    ".\tclibutils_Debug\t_c_array.obj"

    ".\tclibutils_Debug\t_c_deque.obj"

    ".\tclibutils_Debug\t_c_heap.obj"

    ".\tclibutils_Debug\t_c_map.obj"

    ".\tclibutils_Debug\t_c_rb.obj"

    ".\tclibutils_Debug\t_c_set.obj"

    ".\tclibutils_Debug\t_c_slist.obj"

    ".\tclibutils_Debug\t_c_stack.obj"

    ".\tclibutils_Debug\t_clibutils.obj"

    ".\tclibutils_Debug\tclibutils.exe.embed.manifest.res"
    ]
    Creating command line "link.exe @d:\Avinash\work\clibutils\win\tclibutils_Debug\RSP0000173148808.rsp /NOLOGO /ERRORREPORT:PROMPT"
    Creating temporary file "d:\Avinash\work\clibutils\win\tclibutils_Debug\RSP0000183148808.rsp" with contents
    [
    /out:.\tclibutils_Debug\tclibutils.exe.embed.manifest /notify_update /manifest

    .\tclibutils_Debug\tclibutils.exe.intermediate.manifest
    ]
    Creating command line "mt.exe @d:\Avinash\work\clibutils\win\tclibutils_Debug\RSP0000183148808.rsp /nologo"
    Creating temporary file "d:\Avinash\work\clibutils\win\tclibutils_Debug\BAT0000193148808.bat" with contents
    [
    @echo Manifest resource last updated at %TIME% on %DATE% > .\tclibutils_Debug\mt.dep
    ]
    Creating command line "d:\Avinash\work\clibutils\win\tclibutils_Debug\BAT0000193148808.bat"

    Output Window
      Linking...
    Embedding manifest...

    Results
      Build log was saved at "file://d:\Avinash\work\clibutils\win\tclibutils_Debug\BuildLog.htm"
    tclibutils - 0 error(s), 0 warning(s)